cytoflowgui package
===================

Subpackages
-----------

.. toctree::

    cytoflowgui.op_plugins
    cytoflowgui.view_plugins

Submodules
----------

cytoflowgui.example_panes module
--------------------------------

.. automodule:: cytoflowgui.example_panes
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.example_task module
-------------------------------

.. automodule:: cytoflowgui.example_task
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.experiment_dialog module
------------------------------------

.. automodule:: cytoflowgui.experiment_dialog
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.flow_task module
----------------------------

.. automodule:: cytoflowgui.flow_task
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.flow_task_pane module
---------------------------------

.. automodule:: cytoflowgui.flow_task_pane
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.matplotlib_editor module
------------------------------------

.. automodule:: cytoflowgui.matplotlib_editor
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.run module
----------------------

.. automodule:: cytoflowgui.run
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.vertical_notebook module
------------------------------------

.. automodule:: cytoflowgui.vertical_notebook
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.view_traits_pane module
-----------------------------------

.. automodule:: cytoflowgui.view_traits_pane
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.workflow_pane module
--------------------------------

.. automodule:: cytoflowgui.workflow_pane
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflowgui
    :members:
    :undoc-members:
    :show-inheritance:
